@@ -7,9 +7,9 @@ Created on 2025/5/24 19:02
 ---------------------------------------------
 """
 
-import quda
 from ._jy_sql import *
 from .. import tables
+import lidb
 
 
 CONFIG = {
@@ -25,4 +25,4 @@ CONFIG = {
 
 def fetch_fn(tb_name, db_conf):
     query = CONFIG.get(tb_name)
-    return quda.read_mysql(query, db_conf=db_conf)
+    return lidb.read_mysql(query, db_conf=db_conf)
