@@ -13,7 +13,7 @@ import polars as pl
 import xcals
 
 import quda.data
-from quda.factor import DATE_FORMAT, Factor
+from quda.factor import DATE_FORMAT, Factor, INDEX
 from .. import tables
 
 
@@ -51,12 +51,12 @@ def share(date, ):
     return res.group_by("asset").tail(1)
 
 
-fac_share = quda.Factor(fn=share)
+fac_share = Factor(fn=share)
 
 
-def cap(this: quda.Factor, date, end_time):
+def cap(this: Factor, date, end_time):
     depend_val = this.get_value_depends(date, time=end_time)
-    depend_val = depend_val.select(*quda.factor.INDEX,
+    depend_val = depend_val.select(*INDEX,
                                    pl.sql_expr("`fac_kline_minute.close` * `fac_share.TotalShares` as total_cap"),
                                    pl.sql_expr("`fac_kline_minute.close` * `fac_share.AShares` as a_cap"),
                                    pl.sql_expr("`fac_kline_minute.close` * `fac_share.AFloats` as afloat_cap"))
@@ -66,7 +66,7 @@ def cap(this: quda.Factor, date, end_time):
                                    afloat_cap_ln=pl.col("afloat_cap").log(), )
 
 
-fac_cap = quda.Factor(fac_kline_minute, fac_share, fn=cap)
+fac_cap = Factor(fac_kline_minute, fac_share, fn=cap)
 
 
 def st(date):
@@ -90,7 +90,7 @@ def st(date):
     return index.join(st_df, on="asset", how="left").fill_null(0)
 
 
-fac_st = quda.Factor(fn=st)
+fac_st = Factor(fn=st)
 
 
 def ipo(date, days: int):
@@ -115,7 +115,7 @@ def ipo(date, days: int):
     return index.join(ipo_df, on="asset", how="left").fill_null(0)
 
 
-fac_ipo = quda.Factor(fn=ipo)
+fac_ipo = Factor(fn=ipo)
 
 
 def industry(date):
@@ -133,10 +133,10 @@ def industry(date):
     return df.group_by("asset").tail(1)
 
 
-fac_industry = quda.Factor(fn=industry)
+fac_industry = Factor(fn=industry)
 
 
-def base_quote(this: quda.Factor, date, end_time, env="dev"):
+def base_quote(this: Factor, date, end_time, env="dev"):
     """盘前能够获取的基本行情信息：昨收/涨跌停/开盘"""
     if date < xcals.today():
         return (
@@ -162,10 +162,10 @@ def base_quote(this: quda.Factor, date, end_time, env="dev"):
     return lidb.read_ck(rt_query, db_conf="DATABASES.ck")
 
 
-fac_base_quote = quda.Factor(fac_kline_day, fn=base_quote).set_end_time("09:00:00").set_insert_time("09:00:00")
+fac_base_quote = Factor(fac_kline_day, fn=base_quote).set_end_time("09:00:00").set_insert_time("09:00:00")
 
 
-def components(this: quda.Factor, date, index_code):
+def components(this: Factor, date, index_code):
     """指数成分股: 使用昨收价来计算权重"""
     ts = pd.to_datetime(date)
     beg_date = (ts - pd.offsets.MonthEnd() - pd.offsets.MonthBegin()).strftime(DATE_FORMAT)
@@ -192,17 +192,17 @@ def components(this: quda.Factor, date, index_code):
           .drop("InnerCode", "EndDate"))
     codes = iw["asset"]
     depend_val = this.get_value_depends(date=date, codes=codes, time=time_)
-    depend_val = depend_val.select(*quda.factor.INDEX,
+    depend_val = depend_val.select(*INDEX,
                                    pl.sql_expr("`fac_base_quote.prev_close` * `fac_share.AFloats` as afloat_cap"), )
     w = depend_val.with_columns(weight=pl.col("afloat_cap") / pl.col("afloat_cap").sum()).drop("afloat_cap")
     return w
 
 
-fac_components = quda.Factor(fac_base_quote, fac_share, fn=components).set_end_time("09:00:00").set_insert_time(
+fac_components = Factor(fac_base_quote, fac_share, fn=components).set_end_time("09:00:00").set_insert_time(
     "09:00:00")
 
 
-def filter(this: quda.Factor, date, end_time, env="dev"):
+def filter(this: Factor, date, end_time, env="dev"):
     """默认过滤因子：过滤 st | ipo <= 90d | limit_up | limit_down"""
     depend_val = this.get_value_depends(date, time=end_time)
     cond_df = (
@@ -221,7 +221,7 @@ def filter(this: quda.Factor, date, end_time, env="dev"):
     return cond_df
 
 
-fac_filter = quda.Factor(fac_st,
+fac_filter = Factor(fac_st,
                          fac_kline_minute,
                          fac_ipo(days=90),
                          fac_base_quote,
@@ -249,7 +249,7 @@ def filter_notindex(date, end_time, index_codes: list[str], env="dev"):
     return res
 
 
-fac_filter_notindex = quda.Factor(fac_base_quote,
+fac_filter_notindex = Factor(fac_base_quote,
                                   fac_components,
                                   fn=filter_notindex,
                                   share_params=["env"]).set_end_time("09:00:00").set_insert_time("09:00:00")
