@@ -11,7 +11,7 @@ import hashlib
 
 import xcals
 from .utils import version_hash
-from .consts import TYPE_REALTIME
+from .consts import TYPE_REALTIME, TYPE_FIXEDTIME
 
 class TimeResolver:
 
@@ -24,6 +24,11 @@ class TimeResolver:
             val_date = xcals.shift_tradeday(val_date, -1)
         return val_date
 
+    @staticmethod
+    def resolve_time(time: str, end_time: str, fac_type: str) -> str:
+        val_time = end_time if fac_type == TYPE_FIXEDTIME else time
+        return val_time
+
 
 class VersionResolver:
 
