@@ -177,3 +177,6 @@ def ts_entropy(expr: pl.Expr, windows, dims):
 
 def ts_zscore(expr: pl.Expr, windows):
     return (expr - ts_mean(expr, windows))/ts_std(expr, windows)
+
+def ts_fill_forward(expr: pl.Expr):
+    return expr.fill_null(strategy="forward").over(**over)
