@@ -10,12 +10,17 @@ Created on 2025/6/8 14:29
 import time
 
 import polars as pl
+import xcals
+
 from quda.data.zoo import base
 import logair
 import ygo
 
 from quda.data.zoo.base import fac_components
 
+pl.Config.set_tbl_cols(20)
+pl.Config.set_tbl_width_chars(1000)
+
 logger = logair.get_logger("test")
 
 def test_components():
@@ -49,10 +54,15 @@ def test_get_value():
 
 def test_get_history():
     test_date = "2025-05-06"
-    data = base.fac_filter.get_history(date=test_date,
-                                       period="-2d",
-                                       # beg_date="2025-01-01",
-                                       time="09:31:00")
+    fac = base.fac_kline_day
+    # data = base.fac_filter.get_history(date=test_date,
+    #                                    period="-2d",
+    #                                    beg_date="2025-01-01",
+                                       # time="09:31:00")
+    data = fac.get_history(date=test_date, period="-2d", time="09:30:00")
+    logger.info(data.filter(date=test_date))
+    prev_date = xcals.shift_tradeday(test_date, -1)
+    data = fac.get_value(date=prev_date)
     logger.info(data)
 
 def test_ipo():
